/**
 * Copyright 2016, Z Lab Corporation. All rights reserved.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _textlintRuleHelper = require("textlint-rule-helper");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var ZEN_HAN = /(?:[\u3400-\u4DBF\u4E00-\u9FFF\uF900-\uFAFF]|[\uD840-\uD87F][\uDC00-\uDFFF]|[ぁ-んァ-ヶ])[A-Za-z]/;
var HAN_ZEN = /[A-Za-z](?:[\u3400-\u4DBF\u4E00-\u9FFF\uF900-\uFAFF]|[\uD840-\uD87F][\uDC00-\uDFFF]|[ぁ-んァ-ヶ])/;
var ALLOW_CHARS = ["、", "。", "「", "」", "（", "）", "｛", "｝", "【", "】", "『", "』"];

exports.default = function (context) {
    var helper = new _textlintRuleHelper.RuleHelper(context);
    var Syntax = context.Syntax,
        getSource = context.getSource,
        RuleError = context.RuleError,
        report = context.report;


    return _defineProperty({}, Syntax.Str, function (node) {
        if (helper.isChildNode(node, [Syntax.Link, Syntax.Image, Syntax.BlockQuote])) {
            return;
        }

        var text = getSource(node);
        var err = false;
        var matches = void 0,
            index = void 0,
            c = void 0;

        matches = text.match(ZEN_HAN);
        if (matches) {
            index = matches.index + 1;
            c = matches[0][0];
            if (ALLOW_CHARS.indexOf(c) < 0 && c !== " ") {
                err = true;
            }
        } else {
            matches = text.match(HAN_ZEN);
            if (matches) {
                index = matches.index;
                c = matches[0][1];
                if (ALLOW_CHARS.indexOf(c) < 0 && c !== " ") {
                    err = true;
                }
            }
        }

        if (err) {
            report(node, new RuleError("全角文字と半角英字の間に半角スペースを入れます。", { index: index }));
        }
    });
};
//# sourceMappingURL=one-white-space-between-zenkaku-and-hankaku-eiji.js.map